@@ -26,8 +26,12 @@ async def _run_servers():
 
     proxies = []
     for name, server in config.servers:
-        # TODO: import QueryProxy implementation and use it
-        proxy = QueryProxy(server, name=name)
+        if server.entrypoint is None:
+            entrypoint = QueryProxy
+        else:
+            entrypoint = server.entrypoint.obj
+
+        proxy = entrypoint(server, name=name)
         proxies.append(proxy)
 
     futures = [asyncio.ensure_future(proxy.run()) for proxy in proxies]
@@ -35,7 +39,9 @@ async def _run_servers():
     if config.ebpf and config.ebpf.enabled:
         logger.info('eBPF redirection enabled')
         logger.info('Wait all proxies to be ready ...')
-        await asyncio.gather(*[proxy.wait_ready() for proxy in proxies],)
+        await asyncio.gather(
+            *[proxy.wait_ready() for proxy in proxies],
+        )
         logger.info('Wait all proxies to be ready ... Done!')
         futures.append(asyncio.ensure_future(run_ebpf_redirection()))
     else:
