@@ -16,10 +16,6 @@ MAX_SIZE_32 = 2 ** 31 - 1
 logger = logging.getLogger('sqproxy.transport')
 
 
-class UnknownRequest(Exception):
-    pass
-
-
 class BrokenPacketError(Exception):  # FIXME: message is app layer and packet is transport layer
     def __init__(self, raw_data, addr):
         self.raw_data = raw_data
@@ -70,7 +66,7 @@ class SourceDatagramStream(DatagramStream):
 
     async def send_packet(self, packet, addr=None, split_size=FRAGMENT_MAX_SIZE):
         if len(packet) <= split_size:
-            await self.send(packet, addr)
+            await self._send(packet, addr)
             return
 
         message_id = random.randint(1, MAX_SIZE_32)
@@ -90,7 +86,7 @@ class SourceDatagramStream(DatagramStream):
                 split_header=True,
             )
 
-            await self.send(b''.join((fragment_header, fragment_tail)), addr)
+            await self._send(b''.join((fragment_header, fragment_tail)), addr)
 
     async def recv_packet(self):
         while True:
@@ -111,7 +107,7 @@ class SourceDatagramStream(DatagramStream):
         """Alias for `send()`, use it instead `send()`
         to explicit difference from `send_packet()`
         """
-        return await self.send(data, addr)
+        return await self._send(data, addr)
 
     async def recv_bytes(self):
         """Alias for `recv()`, use it instead `recv()`
@@ -200,7 +196,8 @@ async def bind(addr, *, cls: typing.Type[SourceDatagramServerType] = None) -> So
     drained = asyncio.Event()
 
     transport, protocol = await loop.create_datagram_endpoint(
-        lambda: Protocol(recvq, excq, drained), local_addr=addr, reuse_address=False
+        lambda: Protocol(recvq, excq, drained),
+        local_addr=addr,
     )
 
     if cls is None:
